@@ -1,4 +1,5 @@
 SERVICES = [
+    "airtable",
     "asana",
     "atlassian",
     "bitbucket",
@@ -35,7 +36,8 @@ SERVICES = [
     "trello",
     "twilio",
     "twitter",
+    "vercel",
     "zoom",
 ]
 
-__all__ = [SERVICES]
+__all__ = [SERVICES]  # type: ignore
