@@ -34,7 +34,8 @@ class Incident:
     title: str
     state: str
     components: List[Component] = attr.ib(
-        default=[], validator=attr.validators.instance_of(list),
+        default=[],
+        validator=attr.validators.instance_of(list),
     )
 
 
@@ -53,9 +54,9 @@ class Summary:
     status: Status
     components: List[Component] = attr.ib(
         default=[],
-        validator=attr.validators.optional(attr.validators.instance_of(list)),
+        validator=attr.validators.instance_of(list),
     )
     incidents: List[Incident] = attr.ib(
         default=[],
-        validator=attr.validators.optional(attr.validators.instance_of(list)),
+        validator=attr.validators.instance_of(list),
     )
