@@ -1,7 +1,8 @@
-from statuscheck.services._statuspage import BaseStatusPageAPI
+from statuscheck.services.bases._statuspageio import BaseStatusPageAPI
 
 
 class ServiceAPI(BaseStatusPageAPI):
     name = "SparkPost"
     domain_id = "7ky1q6zd3fyp"
     status_url = "https://status.sparkpost.com/"
+    service_url = "https://sparkpost.com/"
